@@ -4,6 +4,7 @@ from edam.reader.models.database import recreate_database
 from edam.reader.resolvers.resolver_factory import ResolverFactory
 from edam import SERVER
 from edam.utilities.decorators import timer
+from edam.utilities.utilities import verify_database
 from edam.viewer.app.views import app
 
 
@@ -12,7 +13,7 @@ from edam.viewer.app.views import app
 @click.option('--template', required=True,
               help='template file to parse data with')
 @click.option('--metadata', required=True,
-              help='configuration file to annotate data with')
+              help='metadata file to annotate data with')
 @click.option('--var', required=False, default="",
               help='Extra variables for URI generation')
 @click.option('--drop', required=False, default='no',
@@ -35,11 +36,6 @@ def cli(input_file, template, metadata, var, drop):
             resolver.store_timeseries()
 
 
-def run():
-    app.jinja_env.auto_reload = True
-    app.config['TEMPLATES_AUTO_RELOAD'] = True
-    app.run(host=SERVER['host'], port=SERVER['port'], debug=SERVER['debug'])
-
-
 if __name__ == '__main__':
+    verify_database()
     cli()
