@@ -1,4 +1,5 @@
 from edam import SERVER
+from edam.utilities.utilities import verify_database
 from edam.viewer.app.views import app
 
 
@@ -9,4 +10,5 @@ def run():
 
 
 if __name__ == "__main__":
+    verify_database()
     run()
